# letra
Label management utility for GitHub issues

Early, pre-Alpha, non-functional (yet)

[![Version Badge][version-badge]][pypi-package-url]
[![Downloads Badge][downloads-badge]][pypi-package-url]
[![License Badge][license-badge]][license-url] 

[![Linux CI Badge][linux-ci-badge]][linux-ci-url]
[![Mac CI Badge][mac-ci-badge]][mac-ci-url]
[![Windows CI Badge][windows-ci-badge]][windows-ci-url]  

[![Test Results Badge][tests-badge]][tests-url]
[![Coverage Badge][coverage-badge]][coverage-url]
[![Sonar Quality GateBadge][quality-gate-badge]][sonar-project-url]
[![Code Style Badge][black-badge]][black]


[pypi-package-url]: https://pypi.org/project/letra/
[version-badge]: https://img.shields.io/pypi/v/letra?style=flat-square
[downloads-badge]: https://img.shields.io/pypi/dm/letra?style=flat-square
[license-url]: ./LICENSE
[license-badge]: https://img.shields.io/github/license/swellaby/letra?style=flat-square&color=blue
[downloads-badge]: https://img.shields.io/pypi/dm/letra?style=flat-square
[linux-ci-badge]: https://img.shields.io/azure-devops/build/swellaby/opensource/113/master?label=linux%20build&style=flat-square
[linux-ci-url]: https://dev.azure.com/swellaby/OpenSource/_build/latest?definitionId=113
[mac-ci-badge]: https://img.shields.io/azure-devops/build/swellaby/opensource/90/master?label=mac%20build&style=flat-square
[mac-ci-url]: https://dev.azure.com/swellaby/OpenSource/_build/latest?definitionId=90
[windows-ci-badge]: https://img.shields.io/azure-devops/build/swellaby/opensource/91/master?label=windows%20build&style=flat-square
[windows-ci-url]: https://dev.azure.com/swellaby/OpenSource/_build/latest?definitionId=91
[coverage-badge]: https://img.shields.io/azure-devops/coverage/swellaby/opensource/91/master?style=flat-square
[coverage-url]: https://codecov.io/gh/swellaby/letra
[tests-badge]: https://img.shields.io/azure-devops/tests/swellaby/opensource/113/master?label=unit%20tests&style=flat-square
[tests-url]: https://dev.azure.com/swellaby/OpenSource/_build/latest?definitionId=113&view=ms.vss-test-web.build-test-results-tab
[quality-gate-badge]: https://img.shields.io/sonar/quality_gate/swellaby:letra?server=https%3A%2F%2Fsonarcloud.io&style=flat-square
[sonar-project-url]: https://sonarcloud.io/dashboard?id=swellaby%3Aletra
[black-badge]: https://img.shields.io/badge/code%20style-black-black?style=flat-square
[black]: https://black.readthedocs.io/en/stable/
[contributing]: .github/CONTRIBUTING.md
